package val.gp2x;

import jamvm.VMGp2x;

import java.io.File;
import java.lang.reflect.Constructor;
import java.lang.reflect.Method;
import java.util.Vector;

import val.gp2x.cl.StandardClassLoader;

class BatteryMonitor extends Thread
{
  public boolean finished = true;
  public int interval = 30; // seconds
    
  public void run()
  {
    int elapsed = 0;
    finished = false;

    System.out.println("AppLauncher Battery Monitor started...");
    
    // initialize at off
    VMGp2x.gpioControl(VMGp2x.BATT_LED_OFF);

    while (!finished)
    {
      try
      {
        elapsed++;
        if (elapsed == interval)
        {
          elapsed = 0;
          int level = VMGp2x.getBatteryStatus();
          if (level <= VMGp2x.BATTERY_LOW)
          {
            VMGp2x.gpioControl(VMGp2x.BATT_LED_ON);
            
            // if critical, fast flash the led
            if (level == VMGp2x.BATTERY_CRITICAL)
            {
              Thread.sleep(50);
              VMGp2x.gpioControl(VMGp2x.BATT_LED_OFF);
              Thread.sleep(50);
              VMGp2x.gpioControl(VMGp2x.BATT_LED_ON);
            }
          }
        }
      
        // one second
        Thread.sleep(1000);
      }
      catch (InterruptedException e)
      {
        finished = true;
      }
    }

    // finalize at off
    VMGp2x.gpioControl(VMGp2x.BATT_LED_OFF);

    System.out.println("AppLauncher Battery Monitor ended.");
  }
}

public class AppLauncher
{
  {
    System.loadLibrary("sdljava");
    System.loadLibrary("sdljava_image");
    System.loadLibrary("sdljava_ttf");
    System.loadLibrary("sdljava_mixer");
    System.loadLibrary("sdljava_gfx");
  }

  public static void main(String[] args)
  {
    try
    {
      BatteryMonitor bm = new BatteryMonitor();

      GP2x gp2x = new GP2x();
      ClassLoader sysLoader = ClassLoader.getSystemClassLoader();
      
      boolean finished = false;
      
      while (!finished)
      {
        // start (or restart) the battery monitor
        if (bm.finished)
        {
          bm = new BatteryMonitor();
          bm.start();
        }
        
        FileSystemNavigator fsn = new FileSystemNavigator();

        fsn.initialize(gp2x);
        int ec = fsn.mainLoop();
        String applicationDescriptor = fsn.getDescriptorFileName();
        fsn.finish();
        
        // Do the best to clean things up
        fsn = null;
        System.gc();
        System.runFinalization();
        
        if (ec == FileSystemNavigator.EXITCODE_LOAD)
        {
          System.out.println("Want to load: " + applicationDescriptor);
          AppProperties ap = new AppProperties(applicationDescriptor);
          
          if (ap.isValid())
          {
            File descFile = new File(applicationDescriptor);
            String baseRoot = descFile.getParent();
  
            System.setProperty("application.root.path", baseRoot);
            System.out.println("application.root.path: " + baseRoot);
  
            StandardClassLoader scl = new StandardClassLoader(sysLoader);
            scl.setDebug(1);
            
            scl.addRepository("file:"+baseRoot + File.separator + ap.getMainJar());
            
            Vector v = ap.getExtraClasspath();
            for (int i=0; i<v.size(); i++)
              scl.addRepository("file:" + baseRoot + File.separator + v.get(i));
    
            Class mainClass = Class.forName(ap.getMainClass(), true, scl);
            Constructor c = mainClass.getConstructor(new Class[] { GP2x.class });
            Method m = mainClass.getMethod(ap.getMainMethod(), null);
            
            Object o = c.newInstance( new Object[] { gp2x } );

            if (!ap.wantsBatteryMonitor())
            {
              System.out.println("Waiting for Battery Monitor to stop...");
              // kill the battery monitor
              bm.finished = true;
              System.out.println("Battery Monitor stopped...");
            }
            
            int cpu = ap.getDesiredCpuClock();
            if (cpu != 0)
            {
              VMGp2x.cpuClockControl(cpu);
            }
            
            m.invoke(o, null);
          }
        }
        else
        {
          finished = true;
        }
      }
      
      // kill the battery monitor
      bm.finished = true;

      // end of any game
      gp2x.destroy();
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }
}
