package val.gp2x;

import java.io.FileInputStream;
import java.util.Properties;
import java.util.Vector;

public class AppProperties
{
  // fundamental
  public static final String AL_PROP_MAIN_JAR = "applauncher-main-jar";
  public static final String AL_PROP_MAIN_CLASS = "applauncher-main-class";
  public static final String AL_PROP_MAIN_METHOD = "applauncher-main-method";
  
  // additionals
  public static final String AL_PROP_APP_NAME = "applauncher-app-name";
  public static final String AL_PROP_LOGO_FILE = "applauncher-app-logo";
  
  // class path extra items
  public static final String AL_PROP_CP_COUNT = "applauncher-extra-cp-count";
  public static final String AL_PROP_CP_ITEM = "applauncher-extra-cp-item";
  
  public static final String AL_PROP_CPU_CLOCK = "applauncher-cpu-clock";
  public static final String AL_PROP_BATTERY_MONITOR = "applauncher-battery-monitor";

  private Properties appProp = null;
  private boolean valid = false;
  
  public AppProperties(String appFileName)
  {
    try
    {
      appProp = new Properties();
      appProp.load( new FileInputStream(appFileName));
      valid = isValid();
    }
    catch (Exception e)
    {
      appProp = null;
    }
  }
  
  public boolean isValid()
  {
    boolean res = false;
    
    if (appProp != null)
    {
      if (appProp.getProperty(AL_PROP_MAIN_JAR, null) != null)
        if (appProp.getProperty(AL_PROP_MAIN_CLASS, null) != null)
          if (appProp.getProperty(AL_PROP_MAIN_METHOD, null) != null)
            res = true;
    }
    return res;
  }
  
  public String getMainJar()
  {
    if (valid)
      return appProp.getProperty(AL_PROP_MAIN_JAR, "app.jar");
    
    return null;
  }
  
  public String getMainClass()
  {
    if (valid)
      return appProp.getProperty(AL_PROP_MAIN_CLASS, "gp2x.app.AppLauncherMain");
    
    return null;
  }
  
  public String getMainMethod()
  {
    if (valid)
      return appProp.getProperty(AL_PROP_MAIN_METHOD, "AppLauncherStart");
    
    return null;
  }
  
  public String getAppName()
  {
    if (valid)
      return appProp.getProperty(AL_PROP_APP_NAME, "No Name");
    
    return null;
  }
  
  public String getAppLogo()
  {
    if (valid)
      return appProp.getProperty(AL_PROP_LOGO_FILE, null);
    
    return null;
  }
  
  public boolean wantsBatteryMonitor()
  {
    if (valid)
      return Boolean.parseBoolean(appProp.getProperty(AL_PROP_BATTERY_MONITOR, "true"));
    
    return true;
  }
  
  public int getDesiredCpuClock()
  {
    int cpuClock = 0;
    
    if (valid)
    {
      String sCpuClock = appProp.getProperty(AL_PROP_CPU_CLOCK, "0");
      
      try {
        cpuClock = Integer.parseInt(sCpuClock);
      }
      catch (Exception e) {
        // ignored
      }
    }
    
    return cpuClock;
  }
  
  public Vector getExtraClasspath()
  {
    if (valid)
    {
      Vector v = new Vector();
      
      int count = Integer.parseInt(appProp.getProperty(AL_PROP_CP_COUNT, "0"));
      for (int i=0; i<count; i++)
        v.add(appProp.getProperty(AL_PROP_CP_ITEM + "-" + (i+1), ""));
        
      return v;
    }
    
    return null;
  }
}
