package val.jamtest;

import jamvm.VMGp2x;

import sdljava.x.swig.SDL_Surface;
import val.gp2x.GP2x;


public class JamTest
{
  private GP2x gp2x = null;
  private boolean finished = false;
  
  private int internalSurface = 0;
  private int framerate = 0;

  private int cpuSpeed = 50;
  private int battery = 0;
  private boolean redLedStatus = false;
  private boolean backLightStatus = true;
  private int fontSmooth = 0;
  private int fontZoom = 100;
  
  // ************************ Start *************************************
  public JamTest(GP2x gp2x) throws Exception
  {
    // initialize the screen/joystick hardware devices
    this.gp2x = gp2x;

    SDL_Surface s = gp2x.getFramebuffer().getSwigSurface();
    internalSurface = (int)SDL_Surface.getCPtr(s);
    
    // init the processor speed
    VMGp2x.cpuClockControl(50);
    battery = VMGp2x.getBatteryStatus();
    
    gp2x.resetButtons();
  }

  private void setRedLed(boolean status)
  {
    if (status)
      VMGp2x.gpioControl(VMGp2x.BATT_LED_ON);
    else
      VMGp2x.gpioControl(VMGp2x.BATT_LED_OFF);
  }
  
  private void setBackLight(boolean status)
  {
    if (status)
      VMGp2x.gpioControl(VMGp2x.BACK_LIGHT_ON);
    else
      VMGp2x.gpioControl(VMGp2x.BACK_LIGHT_OFF);
  }
  
  private void upDownCPU(boolean upOrDown)
  {
    if (upOrDown)
      cpuSpeed += 10;
    else
      cpuSpeed -= 10;
    
    if (cpuSpeed < 50) cpuSpeed = 50;
    if (cpuSpeed > 300) cpuSpeed = 300;

    VMGp2x.cpuClockControl(cpuSpeed);
  }

  private void fontZoomAndSmooth()
  {
    VMGp2x.sFont_ScaleFont(fontZoom, fontZoom, fontSmooth);
  }
  

  String[] keys = new String[] {
      "Keys are: ",
      "  L = red led on/off",
      "  R = back light on/off",
      "  Y = update battery",
      "  VOL +/- = CPU Speed",
      "  Up/Down = Font bigger/smaller",
      "  A = Font smooth on/off",
      "  B = Font reset",
      "Start = Quit"
    };

  private void writeStrings(int x, int starty, String[] arr)
  {
    for (int i=0; i<arr.length; i++)
    {
      VMGp2x.sFont_Write(x, starty, arr[i], internalSurface);
      starty+=15;
    }
  }
  
  private void fullRepaint()
  {
      gp2x.clearScreen();
    
      VMGp2x.sFont_Write(0, 0, "FPS = "+framerate+" CPU @"+cpuSpeed+" MHz", internalSurface);
      VMGp2x.sFont_Write(0, 20, "Font Zoom="+fontZoom+" Smooth="+fontSmooth, internalSurface);

      VMGp2x.sFont_WriteCenter(210, "Battery is at "+battery, internalSurface);

      writeStrings(10, 50, keys);
      
      gp2x.repaint();
  }
  
  /**
   * Entry point
   */
  public void mainGameLoop()
  {
    try
    {
      gp2x.clearScreen();
      
      while (!finished)
      {
        long start = System.currentTimeMillis();
        fullRepaint();
        long end = System.currentTimeMillis();
        
        if (end > start)
        {
          framerate = (int)(1000.0 / (end-start));
        }
        
        events();
        Thread.sleep(1);
      }
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
    
  }

  /**
   * Performs actions depending on Clicked/clicked buttons
   */
  public void events() throws Exception
  {
    gp2x.getJoyButtonChanges();

    if (gp2x.isButtonClicked(GP2x.VK_UP)) {
      fontZoom += 10;
      fontZoomAndSmooth();
    }
    if (gp2x.isButtonClicked(GP2x.VK_DOWN)) {
      fontZoom -= 10;
      if (fontZoom < 10) fontZoom = 10;
      fontZoomAndSmooth();
    }
    if (gp2x.isButtonClicked(GP2x.VK_LEFT)) {
    }
    if (gp2x.isButtonClicked(GP2x.VK_RIGHT)) {
    }

    if (gp2x.isButtonClicked(GP2x.VK_UP_LEFT)) {
    }
    if (gp2x.isButtonClicked(GP2x.VK_UP_RIGHT)) {
    }
    if (gp2x.isButtonClicked(GP2x.VK_DOWN_LEFT)) {
    }
    if (gp2x.isButtonClicked(GP2x.VK_DOWN_RIGHT)) {
    }

    if (gp2x.isButtonClicked(GP2x.VK_FY)) {
      battery = VMGp2x.getBatteryStatus();
    }
    if (gp2x.isButtonClicked(GP2x.VK_FX)) {
    }
    if (gp2x.isButtonClicked(GP2x.VK_FA)) {
      if (fontSmooth == 1)
        fontSmooth = 0;
      else
        fontSmooth = 1;
      
      fontZoomAndSmooth();
    }
    if (gp2x.isButtonClicked(GP2x.VK_FB)) {
      fontSmooth = 0;
      fontZoom = 100;
      VMGp2x.sFont_ResetFont();
    }

    if (gp2x.isButtonClicked(GP2x.VK_FL)) {
      redLedStatus = !redLedStatus;
      setRedLed(redLedStatus);
    }
    if (gp2x.isButtonClicked(GP2x.VK_FR)) {
      backLightStatus = !backLightStatus;
      setBackLight(backLightStatus);
    }
    if (gp2x.isButtonClicked(GP2x.VK_TAT)) {
    }

    // QUIT ON START BUTTON
    if (gp2x.isButtonClicked(GP2x.VK_START)) {
      finished = true;
    }
    if (gp2x.isButtonClicked(GP2x.VK_SELECT)) {
    }
    if (gp2x.isButtonClicked(GP2x.VK_VOL_UP)) {
      upDownCPU(true);
    }
    if (gp2x.isButtonClicked(GP2x.VK_VOL_DOWN)) {
      upDownCPU(false);
    }
  }
  
  
  
}
