/*
 $Id: Event.java,v 1.1.1.1 2005/11/14 17:33:29 val Exp $

 This file is part of the Synclast UI API.

 The Synclast UI API is free software; you can redistribute it
 and/or modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2 of
 the License, or (at your option) any later version.

 The Synclast UI API is distributed in the hope that it will be
 useful, but WITHOUT ANY WARRANTY; without even the implied
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with the Synclast UI API; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package com.synclast;


/**
 * Extends MIDP's Command class to allow the source of the command to be known. This allows MIDP's command listener strategy to be employed
 * for events with sources that are not instances of the Displayable interface.
 */
public class Event extends Command
{
  private Object source;

  /**
   * Creates a new event with the given object as its source.
   */
  public Event(Object source, Command command)
  {
    super(command.getCommandType());
    this.source = source;
  }

  /**
   * Retrieves the object which generated the event. The static nature of this method suggests an implementation of commandAction() similar
   * to the following:
   * 
   * <PRE>
   * public void commandAction(Command command, Displayable displayable)
   * {
   *   if (Event.getSource(command) == someWidget)
   *   { // handle events associated with someWidget }
   * }
   * </PRE>
   */
  public static Object getSource(Command command)
  {
    if ( command instanceof Event )
    {
      return ((Event) command).source;
    }
    return null;
  }
}
