package com.synclast;

import sdljava.SDLException;
import sdljava.ttf.SDLTTF;
import sdljava.ttf.SDLTrueTypeFont;
import sdljava.video.SDLColor;
import sdljava.video.SDLSurface;

public class Font
{
  public static final int FACE_SYSTEM = 0;
  public static final int FACE_MONOSPACE = 32;
  public static final int FACE_PROPORTIONAL = 64;
  
  public static final int SIZE_SMALL = 8;
  public static final int SIZE_MEDIUM = 0;
  public static final int SIZE_LARGE = 16;
  
  public static final int STYLE_PLAIN = 0;
  public static final int STYLE_BOLD = 1;
  public static final int STYLE_ITALIC = 2;
  public static final int STYLE_UNDERLINED = 4;

  public static Font defaultFont = null;

  private int face;
  private int style;
  private int size;
  
  private SDLTrueTypeFont font;
  
  private Font(int face, int style, int size)
  {
    this.face = face;
    this.style = style;
    this.size = size;
    
    try
    {
      int fsize;
      String fface;
      int fstyle;
      
      if (size == SIZE_LARGE) fsize = 18;
      else if (size == SIZE_MEDIUM) fsize = 14;
      else if (size == SIZE_SMALL) fsize = 12;
      else fsize = 10;
      
      if (face == FACE_SYSTEM) fface = "fonts/x360.ttf";
      else if (face == FACE_PROPORTIONAL) fface = "fonts/x360.ttf";
      else if (face == FACE_MONOSPACE) fface = "fonts/x360.ttf";
      else fface = "fonts/x360.ttf";
      
      this.font = SDLTTF.openFont(fface, fsize);
      
      fstyle = SDLTrueTypeFont.TTF_STYLE_NORMAL;
      if ((style & STYLE_BOLD) != 0)  fstyle |= SDLTrueTypeFont.TTF_STYLE_BOLD;
      if ((style & STYLE_ITALIC) != 0)  fstyle |= SDLTrueTypeFont.TTF_STYLE_ITALIC;
      if ((style & STYLE_UNDERLINED) != 0)  fstyle |= SDLTrueTypeFont.TTF_STYLE_UNDERLINE;

      this.font.setFontStyle(fstyle);
      
      System.out.println("Font: "+font);
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
  
  public void closeFont()
  {
    try
    {
      this.font.closeFont();
    }
    catch (SDLException e)
    {
      e.printStackTrace();
    }
  }
  
  public SDLSurface writeChars(char[] chars, int start, int length, SDLColor color)
  {
    try {
      return this.font.renderTextBlended(new String(chars, start, length), color);
    } catch (Exception e) {
      e.printStackTrace();
    }
    return null;
  }
  
  public SDLSurface writeString(String s, SDLColor color)
  {
    return writeChars(s.toCharArray(), 0, s.length(), color);
  }
  
  public SDLSurface writeCharsShaded(char[] chars, int start, int length, SDLColor color, SDLColor shade)
  {
    try {
      return this.font.renderTextShaded(new String(chars, start, length), color, shade);
    } catch (Exception e) {
      e.printStackTrace();
    }
    return null;
  }
  
  public SDLSurface writeStringShaded(String s, SDLColor color, SDLColor shade)
  {
    return writeCharsShaded(s.toCharArray(), 0, s.length(), color, shade);
  }
  
  public int charsWidth(char[] chars, int start, int length)
  {
    int cnt = 0;
    
    // first chance to speed up things and avoid crash
    if (chars.length == 0 || length == 0)
      return 0;
    
    try {
      /* FIXME: fix me, font.glyphMetrics does not work ???
        for (int i=start; i<start+length; i++)
          cnt += font.glyphMetrics(chars[i]).getAdvance();
      */
      
      SDLSurface s = writeChars(chars, start, length, new SDLColor(0xFF,0xFF,0xFF));
      cnt = s.getWidth();
      s.freeSurface();
      
    } catch (Exception e) {
      e.printStackTrace();
    }
    
    return cnt;
  }

  public int charWidth(char c)
  {
    return this.charsWidth(new char[]{c}, 0, 1);
  }

  public int stringWidth(String string)
  {
    return this.charsWidth(string.toCharArray(), 0, string.length());
  }

  public int substringWidth(String string, int start, int end)
  {
    String sub = string.substring(start, end);
    return this.charsWidth(sub.toCharArray(), 0, sub.length());
  }

  public static Font getDefaultFont()
  {
    if (defaultFont == null)
      defaultFont = Font.getFont(FACE_PROPORTIONAL, STYLE_BOLD, SIZE_MEDIUM);
    
    return defaultFont;
  }


  public int getBaselinePosition()
  {
    return Math.abs(this.font.fontAscent());
  }

  public int getHeight()
  {
    return this.font.fontHeight();
  }


  public int getStyle()
  {
    return style;
  }


  public int getFace()
  {
    return face;
  }


  public int getSize()
  {
    return size;
  }


  public static Font getFont(int face, int style, int size)
  {
    return new Font(face, style, size);
  }

}
