package com.synclast;

import sdljava.SDLException;
import sdljava.image.SDLImage;
import sdljava.video.SDLColor;
import sdljava.video.SDLRect;
import sdljava.video.SDLSurface;
import sdljava.video.SDLVideo;
import sdljava.x.swig.SDL_Color;
import sdljava.x.swig.SDL_Surface;
import sdljava.x.swig.SWIG_SDLVideo;

public class FontBitmapped
{
  public static final int FACE_SYSTEM = 0;
  
  public static final int STYLE_NORMAL = 0;
  public static final int STYLE_LARGE = 1;

  public static FontBitmapped defaultFont = null;

  private int face;
  private int style;
  private int size;
  
  private SDLSurface font;
  
  private FontBitmapped(int face, int style, int size)
  {
    this.face = face;
    this.style = style;
    this.size = size;
    
    try
    {
      String fface = "";
      
      if (face == FACE_SYSTEM) fface = "fonts/Lucida_";
      else fface = "fonts/Lucida_";
      
      if (style == STYLE_LARGE) fface = fface + "L";

      fface = fface + size + ".bmp";
      
      this.font = SDLImage.load(fface);
      this.font.setColorKey(SDLVideo.SDL_SRCCOLORKEY, 0);

      System.out.println("Font: "+font);
    } catch (Exception e) {
      e.printStackTrace();
    }
  }
  
  public void closeFont()
  {
    try
    {
      this.font.freeSurface();
    }
    catch (SDLException e)
    {
      e.printStackTrace();
    }
  }
  
  public boolean setPalette(SDL_Surface surface, int flags, SDLColor[] colors, int first) throws SDLException
  {
    SDL_Color swigColors[] = new SDL_Color[colors.length];
    for (int i = 0; i < colors.length; i++)
    {
      swigColors[i] = new SDL_Color();
      swigColors[i].setR( (byte)colors[i].getRed() );
      swigColors[i].setG( (byte)colors[i].getGreen() );
      swigColors[i].setB( (byte)colors[i].getBlue() );
    }

    return SWIG_SDLVideo.SWIG_SDL_SetPalette(surface, flags, swigColors, first, colors.length-first) == 1;
  }

  private SDLSurface _internal_writeChars(char[] chars, int start, int length, SDLColor color, SDLColor shade)
  {
    SDLSurface s = null;
    
    try
    {
      SDLRect src = new SDLRect();
      SDLRect dst = new SDLRect();
      dst.height = src.height = this.getHeight();
      dst.width = src.width = this.getWidth();

      s = SDLVideo.createRGBSurface(
        (long)SDLVideo.SDL_SWSURFACE,
        length * this.getWidth(), this.getHeight(),
        8, 0, 0, 0, 0);
      
      if (shade != null)
        s.fillRect((shade.getRed() << 16) + (shade.getGreen() << 8) + (shade.getBlue() << 0));
      
      if (color != null)
      {
        SDLColor[] cccolors = new SDLColor[2];
        cccolors[0] = new SDLColor(0,0,0);
        cccolors[1] = color;
        this.setPalette(s.getSwigSurface(), SWIG_SDLVideo.SDL_LOGPAL, cccolors, 0);
      }
      
      for (int i=0; i<length; i++)
      {
        byte c = (byte)chars[start + i];
        src.y = (c / 16) * dst.height;
        src.x = (c % 16) * dst.width;
        dst.y = 0;
        dst.x = i * dst.width;
        
        font.blitSurface(src, s, dst);
      }
      
      return s;
    }
    catch (Exception e) {
      e.printStackTrace();
    }
    
    return null;
  }
  
  public SDLSurface writeChars(char[] chars, int start, int length, SDLColor color)
  {
    try {
      return this._internal_writeChars(chars, start, length, color, null);
    } catch (Exception e) {
      e.printStackTrace();
    }
    return null;
  }
  
  public SDLSurface writeString(String s, SDLColor color)
  {
    return writeChars(s.toCharArray(), 0, s.length(), color);
  }
  
  public SDLSurface writeCharsShaded(char[] chars, int start, int length, SDLColor color, SDLColor shade)
  {
    try {
      return this._internal_writeChars(chars, start, length, color, shade);
    } catch (Exception e) {
      e.printStackTrace();
    }
    return null;
  }
  
  public SDLSurface writeStringShaded(String s, SDLColor color, SDLColor shade)
  {
    return writeCharsShaded(s.toCharArray(), 0, s.length(), color, shade);
  }
  
  public int charsWidth(char[] chars, int start, int length)
  {
    return (length-start) * this.getWidth();
  }

  public int charWidth(char c)
  {
    return this.charsWidth(new char[]{c}, 0, 1);
  }

  public int stringWidth(String string)
  {
    return this.charsWidth(string.toCharArray(), 0, string.length());
  }

  public int substringWidth(String string, int start, int end)
  {
    String sub = string.substring(start, end);
    return this.charsWidth(sub.toCharArray(), 0, sub.length());
  }

  public static FontBitmapped getDefaultFont()
  {
    if (defaultFont == null)
      defaultFont = FontBitmapped.getFont(FACE_SYSTEM, STYLE_NORMAL, 12);
    
    return defaultFont;
  }


  public int getBaselinePosition()
  {
    return Math.abs(this.getHeight() - 3);
  }

  public int getHeight()
  {
    return this.font.getHeight() / 16;
  }

  public int getWidth()
  {
    return this.font.getWidth() / 16;
  }


  public int getStyle()
  {
    return style;
  }


  public int getFace()
  {
    return face;
  }


  public int getSize()
  {
    return size;
  }


  public static FontBitmapped getFont(int face, int style, int size)
  {
    return new FontBitmapped(face, style, size);
  }

}
