package com.synclast;

import sdljava.SDLException;
import sdljava.video.SDLColor;
import sdljava.video.SDLRect;
import sdljava.video.SDLSurface;
import sdljavax.gfx.SDLGfx;

public class Graphics
{
  public static final int BOTTOM = 1;
  public static final int TOP = 2;
  public static final int LEFT = 4;
  public static final int RIGHT = 8;

  public static final int HCENTER = 16;
  public static final int VCENTER = 32;

  private SDLSurface mySurface = null;
  private SDLRect myClipRect;
  private long myColor;
  private SDLColor mySDLColor;

  private Font myFont;

  private int translateX = 0;
  private int translateY = 0;

  private Graphics()
  {
  }

  public Graphics(SDLSurface surface)
  {
    try
    {
      this.mySurface = surface;
      this.myClipRect = surface.getClipRect();
      this.myFont = Font.getDefaultFont();
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  public void log(String s)
  {
    
  }
  
  
  public SDLSurface getSurface()
  {
    return mySurface;
  }

  public void drawChars(char[] chars, int start, int length, int x, int y, int alignment)
  {
    try
    {
      this.log("Graphics.drawChars [" + start + "] [" + length + "] [" + x + "] [" + y + "] [" + alignment + "] ["
          + (new String(chars, start, length)) + "]");

      if (chars == null || chars.length <= 0 || length <= 0)
        return;

      SDLSurface s = myFont.writeChars(chars, start, length, mySDLColor);
      s.blitSurface(mySurface, new SDLRect(x + translateX, y + translateY));
    }
    catch (SDLException e)
    {
      e.printStackTrace();
    }
  }

  public void drawString(String string, int x, int y, int alignment)
  {
    try
    {
      this.log("Graphics.drawString [" + x + "] [" + y + "] [" + alignment + "] [" + string + "]");

      if (string == null || string.length() <= 0)
        return;
      
      SDLSurface s = myFont.writeChars(string.toCharArray(), 0, string.length(), mySDLColor);
      s.blitSurface(mySurface, new SDLRect(x + translateX, y + translateY));
    }
    catch (SDLException e)
    {
      e.printStackTrace();
    }
  }

  public void drawImage(Image image, int x, int y, int alignment)
  {
    try
    {
      if ((alignment & HCENTER) != 0)
        x -= image.getWidth() / 2;
      if ((alignment & VCENTER) != 0)
        y -= image.getWidth() / 2;
      
      SDLRect rect = new SDLRect(x + translateX, y + translateY);
      this.log("Graphics.drawImage [" + image + "] ["+alignment+"] at " + rect);
      image.getGraphics().getSurface().blitSurface(mySurface, rect);
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  public void drawRect(int x, int y, int w, int h)
  {
    this.log("Graphics.drawRect [" + x + "] [" + y + "] [" + w + "] [" + h + "]");
    SDLGfx.rectangleColor(mySurface, x + translateX, y + translateY, w + x + translateX, h + y + translateY, myColor);
  }

  public void drawRoundRect(int x, int y, int w, int h, int arc1, int arc2)
  {
    this.log("Graphics.drawRoundRect [" + x + "] [" + y + "] [" + w + "] [" + h + "] [" + arc1 + "] [" + arc2 + "]");
    SDLGfx.rectangleColor(mySurface, x + translateX, y + translateY, w + x + translateX, h + y + translateY, myColor);
  }

  public void fillRect(int x, int y, int w, int h)
  {
    try
    {
      this.log("Graphics.fillRect [" + x + "] [" + y + "] [" + w + "] [" + h + "]");
      mySurface.fillRect(new SDLRect(x + translateX, y + translateY, w, h), myColor);
    }
    catch (SDLException e)
    {
      e.printStackTrace();
    }
  }

  public void drawLine(int x1, int y1, int x2, int y2)
  {
    this.log("Graphics.drawLine [" + x1 + "] [" + y1 + "] [" + x2 + "] [" + y2 + "]");
    SDLGfx.lineColor(mySurface, x1 + translateX, y1 + translateY, x2 + translateX, y2 + translateY, myColor);
  }

  public void fillRoundRect(int x, int y, int w, int h, int arc1, int arc2)
  {
    try
    {
      this.log("Graphics.fillRoundRect [" + x + "] [" + y + "] [" + w + "] [" + h + "] [" + arc1 + "] [" + arc2 + "]");
      mySurface.fillRect(new SDLRect(x + translateX, y + translateY, w, h), myColor);
    }
    catch (SDLException e)
    {
      e.printStackTrace();
    }
  }

  public int getClipHeight()
  {
    return myClipRect.getHeight();
  }

  public int getClipWidth()
  {
    return myClipRect.getWidth();
  }

  public int getClipX()
  {
    return myClipRect.getX();
  }

  public int getClipY()
  {
    return myClipRect.getY();
  }

  public void setClip(int x, int y, int w, int h)
  {
    this.myClipRect = new SDLRect(x, y, w, h);
    this.log("Graphics.this.myClipRect [" + this.myClipRect + "]");
  }

  public void clipRect(int x, int y, int w, int h)
  {
    setClip(x, y, w, h);
    this.log("Graphics.clipRect [" + this.myClipRect + "]");
  }

  public void setFont(Font font)
  {
    this.myFont = font;
  }

  public void translate(int x, int y)
  {
    this.translateX += x;
    this.translateY += y;
    this.log("Graphics.translate [" + x + "] [" + y + "]");
  }

  public int getTranslateX()
  {
    return this.translateX;
  }

  public int getTranslateY()
  {
    return this.translateY;
  }

  public void setColor(int i)
  {
    byte r = (byte) ((i & 0x00FF0000) >> 16);
    byte g = (byte) ((i & 0x0000FF00) >> 8);
    byte b = (byte) (i & 0x000000FF);
    try
    {
      this.myColor = mySurface.mapRGB(r, g, b);
      this.mySDLColor = new SDLColor(r, g, b);
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  public int getWidth()
  {
    return this.mySurface.getWidth();
  }

  public int getHeight()
  {
    return this.mySurface.getHeight();
  }

}
