/*
    $Id: SynclastManager.java,v 1.1.1.1 2005/11/14 17:33:29 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast;


import val.gp2x.GP2x;

/**
 * Provides a central mechanism for Synclast API components to
 * have access to application-specific configuration information.
 */
public class SynclastManager {
    private static final String VERSION = "0.2";
    private static final String PROPERTY_PREFIX = "Synclast-";

    private static Environment config;

    // SynclastManager should never be constructed
    private SynclastManager() { }
    
    /** Initializes the Synclast toolkit. */
    public static void init(Environment config) {
        SynclastManager.config = config;
    }
    
    /**
     * Returns the Synclast property (for MIDlets, the application
     * property prefaced with "Synclast-") value for the given property.
     */
    public static String getProperty(String key) {
        return (config == null) ? null : 
          config.getAppProperty(PROPERTY_PREFIX + key);
    }

    public static GP2x getGP2x()
    {
      return config.getGP2x();
    }
    
    /**
     * Returns the version of the Synclast API being used.
     */
    public static String getAPIVersion() {
        return VERSION;
    }

}
