/*
    $Id: SynclastTask.java,v 1.2 2005/11/18 09:55:33 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast;

import java.util.Date;
import java.util.Timer;
import java.util.TimerTask;

/**
 * Provides an easy way to adapt any Runnable object into a TimerTask.
 * A common use might be to implement a recurring game loop that
 * executes at a well-defined rate, regardless of device speed.
 * The Synclast subsystem maintains a single instance of a java.util.Timer;
 * immediately upon construction, a new instance of SynclastTask registers
 * itself with the timer.
 */
public class SynclastTask extends TimerTask {
  //static final ??
    private Timer TIMER = new Timer();

    private Runnable runnable;

    /** 
     * Schedules the run() method of the runnable instance to be invoked
     * at the time specified.
     */
    public SynclastTask(Runnable runnable, Date date) {
        this.runnable = runnable;
        TIMER.schedule(this, date);
    }

    /**
     * Schedules the runnable to be run starting at the initial time
     * and repeating with the given period.  If fixedRate is set to false,
     * the period specifies a fixed delay between the end of one run and
     * the beginning of another.
     */
    public SynclastTask(Runnable runnable, Date firstTime, long period, boolean fixedRate) {
        this.runnable = runnable;
        if (fixedRate) {
            TIMER.scheduleAtFixedRate(this, firstTime, period);
        } else {
            TIMER.schedule(this, firstTime, period);
        }
    }

    /**
     * Schedules the runnable to be run starting after the given delay
     * and repeating with the given period.  If fixedRate is set to false,
     * the period specifies a fixed delay between the end of one run and
     * the beginning of another.
     */
    public SynclastTask(Runnable runnable, long delay, long period, boolean fixedRate) {
        this.runnable = runnable;
        if (fixedRate) {
            TIMER.scheduleAtFixedRate(this, delay, period);
        } else {
            TIMER.schedule(this, delay, period);
        }
    }
    
    /** 
     * This method delegates to the run() method of the registered
     * Runnable. 
     */
    public void run() {
        runnable.run();
    }
}
