package com.synclast.test;

import java.util.Hashtable;
import java.util.Vector;


import com.synclast.BaseCanvas;
import com.synclast.Command;
import com.synclast.Environment;
import com.synclast.Event;
import com.synclast.Font;
import com.synclast.Graphics;
import com.synclast.ui.Button;
import com.synclast.ui.Color;
import com.synclast.ui.Label;
import com.synclast.ui.Popup;
import com.synclast.ui.SynclastCanvas;
import com.synclast.ui.containers.Container;
import com.synclast.ui.extra.AnimatedImage;

/**
 * defines the interface a VO Screen must implement
 */

public abstract class BaseScreen implements Runnable
{
  private AnimatedImage networkActivityImage = null;
  private Button quitButton = null;
  
  public AnimatedImage getNetworkActivityImage()
  {
    return networkActivityImage;
  }
  
  public void setNetworkActivityImage(AnimatedImage networkActivityImage)
  {
    this.networkActivityImage = networkActivityImage;
  }
  
  protected static String getBackgroundImageName(String screenName)
  {
    if (screenName.equals(ScreenChat.myName))
      return "sfondi/s_chatwith.gif";
    
    return  null;
  }
  
  protected static Container getDefaultContainer(BaseScreen screen)
  {
    Container container = new Container();
    /*
    container.setBackgroundImage(
        TestRuntimeData.getInstance().getImage(getBackgroundImageName(screen.getMyName()))
        );
    */
    // Add the network activity animation
    Vector bananarap = new Vector();
    bananarap.addElement( TestRuntimeData.getInstance().getImage("banana/bananarap1.gif") );
    bananarap.addElement( TestRuntimeData.getInstance().getImage("banana/bananarap2.gif") );
    bananarap.addElement( TestRuntimeData.getInstance().getImage("banana/bananarap3.gif") );
    bananarap.addElement( TestRuntimeData.getInstance().getImage("banana/bananarap4.gif") );
    AnimatedImage ai = new AnimatedImage("bananarap", bananarap);
    container.add(ai).validate();
    ai.setVisible(false);
    ai.setPosition(176-ai.getWidth(),0,Graphics.LEFT|Graphics.TOP);
    ai.stopAnim();
    
    screen.setNetworkActivityImage(ai);

    return container;
  }
  
  protected static void placeQuitButton(BaseScreen screen, Container container)
  {
    // Add the Quit Button
    if (screen.quitButton == null)
      screen.quitButton = new Button("Quit");
    
    container.remove(screen.quitButton);
    container.add(screen.quitButton).validate();
    screen.quitButton.setPosition(0,208-screen.quitButton.getHeight(),Graphics.LEFT|Graphics.TOP);
  }

  protected static SynclastCanvas finalizeCanvas(BaseScreen screen, Container container)
  {
    placeQuitButton(screen, container);

    // Build the final Canvas
    container.focus();
    SynclastCanvas sc = new SynclastCanvas(container, TestRuntimeData.getInstance().getVOstyle());
    sc.setBackgroundColor(Color.TRANSPARENT);
    
    return sc;
  }
  
  /****************************************************************
   * SCREEN AND CANVAS      SCREEN AND CANVAS        SCREEN AND CANVAS
   ****************************************************************/
  
  // repositories for screen and canvas instances
  private static Hashtable allMyCanvas = new Hashtable();
  private static Hashtable allMyScreen = new Hashtable();
  public static SynclastCanvas getMyCanvas(String cName)
  {
    return (SynclastCanvas)allMyCanvas.get(cName);
  }
  public static void setMyCanvas(String cName, SynclastCanvas c)
  {
    allMyCanvas.put(cName, c);
  }
  public static BaseScreen getInstanceOf(String screenName)
  {
    Object o = allMyScreen.get(screenName);
    if (o != null)
      return (BaseScreen)o;
    
    if (screenName.equals(ScreenChat.myName))
      o = new ScreenChat();
    
    allMyScreen.put(screenName, o);
    return (BaseScreen)o;
  }

  /****************************************************************
   * ABSTRACTS  ABSTRACTS  ABSTRACTS  ABSTRACTS  ABSTRACTS   
   ****************************************************************/
  
  /**
   * Build the Canvas to be presented
   * 
   * @return a Canvas object, it should be a SynclastCanvas instance.
   */
  abstract public BaseCanvas createScreen(Environment midlet, int width, int height);
  
  /**
   * Return the screen canonical name
   * 
   * @return a String
   */
  abstract public String getMyName();
  
  /**
   * handle an event
   * 
   * @return true if the event was handled
   */
  public EventResult handleEvent(Command command)
  {
    EventResult ver = new EventResult();
    ver.handled = false;

    if (Event.getSource(command) == quitButton)
    {
      ver.nextStep = EventResult.QUIT;
      ver.handled = true;
    }
    
    return ver;
  }

  /****************************************************************
   * THREAD      THREAD      THREAD      THREAD    THREAD
   ****************************************************************/
  
  protected Thread myThread = null;
  protected boolean shouldStopThread = false;

  protected void stopThread()
  {
    if (myThread != null)
    {
      try
      {
        this.shouldStopThread = true;
        myThread.join();
      }
      catch (InterruptedException e)
      {
      }
    }
    
    myThread = null;
  }
  
  protected void startThread()
  {
    this.stopThread();
    this.shouldStopThread = false;
    myThread = new Thread(this);
    myThread.start();
  }

  // a run() that does nothing
  public void run()
  {
  }
  
  /****************************************************************
   * UTILITIES      UTILITIES      UTILITIES      UTILITIES 
   ****************************************************************/

  /**
   * Shows a message
   * @param message
   */
  public void showMessage(String cName, String message)
  {
    TestUtils.DEBUG("SM: "+message);
    showPopupMessage(cName, message);
  }

  public void showPopupMessage(String cName, String message)
  {
    // Flash the new mode name
    // TODO make this more configurable
    Label messageInfo = new Label(message, Font.getDefaultFont());
    messageInfo.set(Label.BACKGROUND_COLOR, Color.WHITE);
    Popup popup = new Popup(messageInfo, 1500);
    popup.setPosition(0, 0, Graphics.LEFT | Graphics.TOP);
    BaseScreen.getMyCanvas(cName).add(popup);
    BaseScreen.getMyCanvas(cName).repaint();
  }

}
