package com.synclast.test;

import java.util.Properties;


import val.gp2x.GP2x;

import com.synclast.BaseCanvas;
import com.synclast.Command;
import com.synclast.CommandListener;
import com.synclast.Environment;
import com.synclast.SynclastManager;
import com.synclast.ui.SynclastCanvas;

public class TestMain implements CommandListener
{
  private Environment myConfig = null;
  private BaseScreen currentScreen = null;
  private BaseCanvas currentCanvas = null;

  {
    System.loadLibrary("sdljava");
    System.loadLibrary("sdljava_image");
    System.loadLibrary("sdljava_ttf");
  }

  public static void main(String[] s) throws Exception
  {
    TestMain tm = new TestMain();

    tm.startApp();

    while (true)
    {
      tm.updateEvents();
      Thread.sleep(33);
    }
    
    /**
     * qui ci va il main loop
     */

    // tm.destroyApp(true);
  }

  // ************************ Start *************************************
  public void startApp()
  {
    try
    {
      // initialize the screen/joystick devices
      GP2x gp2x = new GP2x();
      Properties env = new Properties();

      myConfig = new Environment(gp2x, env);

      SynclastManager.init(myConfig);

      switchToCanvas(ScreenChat.myName);
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }

  }

  public void switchToCanvas(String canvasName)
  {
    BaseCanvas c = null;
    BaseScreen s = null;

    c = BaseScreen.getMyCanvas(canvasName);
    s = BaseScreen.getInstanceOf(canvasName);
    if ( c == null )
    {
      if ( s != null )
      {
        c = s.createScreen(myConfig, 0, 0);
        c.setCommandListener(this);
        BaseScreen.setMyCanvas(canvasName, (SynclastCanvas) c);
      }
    }

    if ( s != null && c != null )
    {
      this.currentScreen = s;
      this.currentCanvas = c;
    }
  }

  public boolean events()
  {
    GP2x gp2x = SynclastManager.getGP2x();
    try
    {
      if ( gp2x.getJoyButtonChanges() )
      {
        if ( gp2x.isButtonClicked(GP2x.VK_UP) )
        {
          this.currentCanvas.keyPressed(BaseCanvas.UP);
        }
        if ( gp2x.isButtonClicked(GP2x.VK_DOWN) )
        {
          this.currentCanvas.keyPressed(BaseCanvas.DOWN);
        }
        if ( gp2x.isButtonClicked(GP2x.VK_LEFT) )
        {
          this.currentCanvas.keyPressed(BaseCanvas.LEFT);
        }
        if ( gp2x.isButtonClicked(GP2x.VK_RIGHT) )
        {
          this.currentCanvas.keyPressed(BaseCanvas.RIGHT);
        }
  
        if ( gp2x.isButtonClicked(GP2x.VK_FX) )
        {
          this.currentCanvas.keyPressed(BaseCanvas.FIRE);
        }

        return true;
      }
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
    
    return false;
  }

  private void updateEvents()
  {
    if ( events() ) this.currentCanvas.repaint();
  }

  public void pauseApp()
  {
  }

  public void destroyApp(boolean unconditional)
  {
  }

  public void commandAction(Command command, BaseCanvas displayable)
  {
    System.out.println("WOW: command: " + command);
    this.currentScreen.handleEvent(command);
  }

}
