/*
    $Id: Button.java,v 1.5 2005/11/25 14:52:55 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui;

import com.synclast.BaseCanvas;
import com.synclast.Command;
import com.synclast.Font;
import com.synclast.Image;


import com.synclast.Event;

/**
 * Encapsulates a selectable widget which may contain either an image
 * or static text.
 */
public class Button extends Label implements KeyEventListener {
    // Workaround for MIDP 1.0 .class access
    public static Class _class = new Button("").getClass();

    public Button(String text) {
      super(text);
  }

    public Button(String text, int w, int h) {
      super(text);
      this.w = w;
      this.h = h;
  }

    public Button(String text, Font font) {
        super(text, font);
    }

    public Button(Image image) {
        super("");
        w = image.getWidth();
        h = image.getHeight();
        setBackgroundImage(image);
    }

    protected void init() {
        super.init();
        set(BORDER_COLOR, Color.BLACK);
        set(BORDER_WIDTH, 1);
        set(INSET_WIDTH, 2);
    }

    public void focus() {
        properties[BORDER_WIDTH]++;
        properties[INSET_WIDTH]--;
        repaint();
    }

    public void blur() {
        properties[BORDER_WIDTH]--;
        properties[INSET_WIDTH]++;
        repaint();
    }

    public void keyPressed(int keyCode) {
        switch (container.getContext().getGameAction(keyCode)) {
        case BaseCanvas.FIRE:
            fireEvent(new Event(this, Command.SELECT_COMMAND));
            break;
        case BaseCanvas.UP:
        case BaseCanvas.LEFT:
            container.passFocus(-1);
            break;
        case BaseCanvas.DOWN:
        case BaseCanvas.RIGHT:
            container.passFocus(1);
            break;
        }
    }

    public void keyRepeated(int keyCode) { }
    public void keyReleased(int keyCode) { }
}
