/*
    $Id: Checkbox.java,v 1.2 2005/11/18 17:54:12 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui;

import com.synclast.BaseCanvas;
import com.synclast.Command;
import com.synclast.Graphics;

import com.synclast.Event;

/**
 * A selectable widget that represents a boolean choice input.
 */
public class Checkbox extends ColoredWidget implements KeyEventListener {
    // Workaround for MIDP 1.0 .class access
    public static Class _class = new Checkbox(false).getClass();

    protected boolean value;

    public Checkbox(boolean initialState) {
        value = initialState;
        w = h = 11;
    }

    protected void init() {
        super.init();
        set(BORDER_WIDTH, 1);
        set(BORDER_COLOR, Color.BLACK);
        set(BACKGROUND_COLOR, Color.LIGHT_GRAY);
    }

    public boolean isSelected() {
        return value;
    }

    public void focus() {
        properties[BORDER_WIDTH]++;
        repaint();
    }

    public void blur() {
        properties[BORDER_WIDTH]--;
        repaint();
    }

    public void keyPressed(int keyCode) {
        switch (container.getContext().getGameAction(keyCode)) {
        case BaseCanvas.FIRE:
            value = !value;
            repaint();
            fireEvent(new Event(this, Command.SELECT_COMMAND));
            break;
        case BaseCanvas.UP:
            container.passFocus(-1);
            break;
        case BaseCanvas.DOWN:
            container.passFocus(1);
            break;
        }
    }

    public void paint(Graphics graphics) {
        super.paint(graphics);
        if (value) {
            // Draw an X -- this could be made prettier
            graphics.drawLine(0,0,
                              graphics.getClipWidth() - 1,
                              graphics.getClipHeight() - 1);
            graphics.drawLine(0, graphics.getClipHeight() - 1,
                              graphics.getClipWidth() - 1, 0);
        }
    }

    public void keyRepeated(int keyCode) { }
    public void keyReleased(int keyCode) { }
}
