/*
    $Id: Label.java,v 1.4 2005/11/28 13:14:35 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui;

import com.synclast.Font;
import com.synclast.Graphics;
import com.synclast.StyleSheet;

/**
 * A widget with a text component displayed in a given font.
 */
public class Label extends ColoredWidget {
    public static final int FONT = ColoredWidget.LAST_PROPERTY + 1;
    
    protected static final int LAST_PROPERTY = FONT;

    // Workaround for MIDP 1.0 .class access
    public static Class _class = new Label("").getClass();

    // Although MIDP has a Font.stringWidth() function, I would
    // tend to assume that the implementation of it still needs
    // to look at the individual characters, so by storing this
    // as a char[] we're possibly getting a slight performance boost.
    protected char[] text;
    protected Font font;

    /**
     * Creates a new label widget with the given text.  The text will
     * be displayed in the default font.
     *
     * @exception NullPointerException if text is null.
     */
    public Label(String text) {
        this(text, Font.getDefaultFont());
    }

    /**
     * Creates a new label widget with the given text and font style.
     *
     * @exception NullPointerException if text or font is null.
     */
    public Label(String text, Font font) {
        this.text = text.toCharArray();
        this.font = font;
        w += font.charsWidth(this.text, 0, this.text.length);
        h += font.getHeight();
    }

    protected void init() {
        super.init();
        set(INSET_WIDTH, 2);
    }

    protected int getPropertyCount() {
        return LAST_PROPERTY + 1;
    }

    public void paint(Graphics graphics) {
        if (this.invisible)
          return;
      
        super.paint(graphics);
        if (text.length > 0) {
            graphics.setFont(font);
            graphics.drawChars(text, 0, text.length, 0, 0,
                               Graphics.TOP | Graphics.LEFT);
        }
    }

    public Widget set(int property, int value) {
        if (property == FONT) {
            w -= font.charsWidth(text, 0, text.length);
            h -= font.getHeight();
            font = StyleSheet.getFont(value);
            w += font.charsWidth(text, 0, text.length);
            h += font.getHeight();
        }
        return super.set(property, value);
    }
    
    public void setText(String text)
    {
      this.text = text.toCharArray();
    }
}
