/*
    $Id: Popup.java,v 1.1.1.1 2005/11/14 17:33:30 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui;


import com.synclast.Graphics;
import com.synclast.ui.containers.Container;

/**
 * Provides a popup that times out after a given amount of time.
 * The clock starts ticking when the widget is added to the container.
 * A Popup instance wraps another widget and mitigates its
 * visibility to the container.
 */
public class Popup extends Widget implements Runnable {
    private int millis;
    private Widget widget;

    public Popup(Widget widget, int millis) {
        this.widget = widget;
        this.millis = millis;
        w = widget.w;
        h = widget.h;
    }

    public void paint(Graphics graphics) {
        widget.paint(graphics);
    }

    public void setContainer(Container container) {
        super.setContainer(container);
        widget.x = x;
        widget.y = y;
        widget.setContainer(container);
        new Thread(this).start();
    }

    public void run() {
        try {
            Thread.sleep(millis);
        } catch (InterruptedException e) {
        }
        if (container != null) {
            container.remove(this);
        }
    }
}
