/*
    $Id: RadioButton.java,v 1.1.1.1 2005/11/14 17:33:30 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui;


import com.synclast.Event;
import com.synclast.Graphics;

/**
 * A RadioButton must be constructed with its RadioGroup owner.
 * The currently selected button can be obtained by calling the
 * appropriate method on RadioGroup, or by individually checking
 * the selected status of each radio button.
 * Note that each RadioButton instance must be added to a
 * canvas/container.  Each individual button may have a String value
 * associated with it.
 */
public class RadioButton extends Button {
    // Workaround for MIDP 1.0 .class access
    public static Class _class = new RadioButton().getClass();
    private RadioButton() { super(""); }

    protected RadioGroup group;
    protected String value;
    protected boolean selected;

    public RadioButton(RadioGroup group, String value) {
        super("");
        this.group = group;
        this.value = value;
        group.add(this);
        w = h = 11;
    }

    protected void init() {
        super.init();
        set(BACKGROUND_COLOR, Color.LIGHT_GRAY);
        set(BORDER_COLOR, Color.BLACK);
        set(BORDER_ARC, 6);
        set(BORDER_WIDTH, 1);
    }

    public boolean isSelected() {
        return selected;
    }

    public void setSelected(boolean value) {
        selected = value;
        repaint();
    }

    public String getValue() {
        return value;
    }

    public RadioGroup getGroup() {
        return group;
    }

    public void paint(Graphics graphics) {
        super.paint(graphics);
        if (selected) {
            // Paint a dot in the middle
            int borderWidth = properties[BORDER_WIDTH];
            graphics.fillRoundRect(borderWidth + 2,
                                   borderWidth + 2,
                                   w - borderWidth * 2 - 4,
                                   h - borderWidth * 2 - 4,
                                   properties[BORDER_ARC],
                                   properties[BORDER_ARC]);
        }
    }

    /**
     * Overrides fireEvent on Button to notify the RadioGroup
     * of the selection.
     */
    protected boolean fireEvent(Event event) {
        group.select(this);
        return super.fireEvent(event);
    }
}
