/*
    $Id: RadioGroup.java,v 1.1.1.1 2005/11/14 17:33:30 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui;

import java.util.Vector;

/**
 * Provides access to a set of RadioButton objects.  In normal usage,
 * an instance of this class is constructed, and then individual
 * RadioButton instances are constructed referencing the group.
 * Each button should be added to the canvas/container individually.
 * The group object provides a convenient way of accessing the
 * selected value from a set of buttons.  
 */
public class RadioGroup {
    protected Vector buttons = new Vector();
    protected int selected = -1;

    public RadioGroup() { }

    void add(RadioButton button) {
	if (button.selected) {
	    selected = buttons.size();
	}
	buttons.addElement(button);
    }

    public void select(RadioButton button) {
	if (selected != -1) {
	    ((RadioButton) buttons.elementAt(selected)).setSelected(false);
	}
	selected = buttons.indexOf(button);
	button.setSelected(true);
    }

    /**
     * Returns the currently selected radio button of this group,
     * or null.
     */
    public RadioButton getSelected() {
	return (selected == -1) ? null : 
	    (RadioButton) buttons.elementAt(selected);
    }

    /**
     * Convenience method to get the value of the currently selected
     * radio button.
     */
    public String getSelectedValue() {
	return (selected == -1) ? null : 
	    ((RadioButton) buttons.elementAt(selected)).value;
    }
}
