/*
    $Id: TapInputAdapter.java,v 1.1.1.1 2005/11/14 17:33:31 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui;


/**
 * Implements the "multitap" method of text entry.  Each digit key is mapped
 * to several letters, numbers or symbols.  Two instances of this adapter
 * are made available by default; these are "Tap-Upper" and "Tap-Lower".
 * Note, however, that the exact symbols assigned to each key may not match
 * the "native" text entry applications for the device.  To address this,
 * you may want to override the configuration for those named adapters via
 * the JAD file.  This approach allows configuration to occur without any
 * code changes between different deployment versions.
 */
public class TapInputAdapter extends InputAdapter {
    protected int TAP_TIMEOUT = 1000;
    protected String[] mapping;

    // NOKIA_3650_MAPPING = " 0{CR}", ".,?!1@'-_():;&/%*#+<=>\"${pound}{section}{yen}{general currency symbol}{vertical bar?}{inverted ?}",
    // "abc2{a umlaut}{ae}{a circle}{a grave}{a acute}{a circumflex}{a tilde}{c cedilla}"
    // "def3{e grave}{e acute}{e circumflex}{e umlaut}{eth}"
    // "ghi4{i grave}{i acute}{i circumflex}{i umlaut}
    // "jkl5{pound}"
    // "mno6{o umlaut}{thorn}{o grave}{o acute}{o circumflex}{o tilde}{n tilde}"
    // "pqrs7{sz ligature}$"
    // "tuv8{u grave}{u acute}{u circumflex}{u umlaut}
    // "wxyz9{y acute}{thorn}"
    
    // Sanyo 8100: LSK=21, RSK=22, Camera button has no keycode,
    //   BACK=255

    private int lastDigit = -1;
    private int index;
    private long timestamp;

    /**
     * Configures the adapter.  The configuration string is formatted
     * as  a comma-separated list of the
     * mappings for the ten digits, starting with 0.  A backslash can
     * be used to escape a comma.  Following this list you may append
     * after a comma {clearKeyCode},{shiftKeyCode} as for the superclass.
     */
    public void configure(String parameters) { 
        int pos = 0;
        int index = 0;
        StringBuffer temp = new StringBuffer();
        mapping = new String[10];
        int len = parameters.length();
        while ((pos < len) && (index < 10)) {
            char ch = parameters.charAt(pos++);
            if (ch == '\\') {
                ch = parameters.charAt(pos++);
            } else if (ch == ',') {
                mapping[index++] = temp.toString();
                temp.setLength(0);
                continue;
            }
            temp.append(ch);
        }
        if (pos >= len) {
            // Add final item
            mapping[index] = temp.toString();
        } else {
            super.configure(parameters.substring(pos));
        }
    }

    public void keyPressed(int keyCode) {
        switch (keyCode) {
        case '#':
            index = 0;
            lastDigit = -1;
            handler.addCharacter(' ');
            return;
        case '0':
        case '1':
        case '2':
        case '3':
        case '4':
        case '5':
        case '6':
        case '7':
        case '8':
        case '9':
            int digit = (int) (keyCode - '0');
            String keyMap = mapping[digit];
            long now = System.currentTimeMillis();
            if ((digit == lastDigit) && ((now - timestamp) < TAP_TIMEOUT)) {
                index++;
                if (index >= keyMap.length()) {
                    index = 0;
                }
                handler.backspace();
            } else {
                index = 0;
                // lastDigit = (pos < properties[CHAR_LENGTH]) ? digit : -1;
                lastDigit = digit;
            }
            // Feed the real character to Input
            handler.addCharacter(keyMap.charAt(index));
            timestamp = now;
            return;
        }
        lastDigit = -1;
        super.keyPressed(keyCode);
    }
}
