package com.synclast.ui.extra;

import java.util.Vector;

import com.synclast.Image;
import com.synclast.ui.*;

// import com.vodafone.chatlet.VOMidletUtils;

/**
 * Provides a popup that times out after a given amount of time. The clock starts ticking when the widget is added to the container. A Popup instance wraps
 * another widget and mitigates its visibility to the container.
 */
public class AnimatedImage extends SynclastImage implements Runnable
{
  private Vector frames;
  private boolean shouldStop = false;
  private Thread myThread = null;
  
  public AnimatedImage(String name, Vector images)
  {
    super((Image)images.elementAt(0));
    frames = images;
  }

  public void stopAnim()
  {
    if (myThread != null)
    {
      try
      {
        this.shouldStop = true;
        myThread.join();
      }
      catch (InterruptedException e)
      {
      }
    }
    
    myThread = null;
  }

  public void startAnim()
  {
    this.shouldStop = false;
    myThread = new Thread(this);
    myThread.start();
  }
  
  /** 
   * Called when the canvas is first shown.
   */
  public void showNotify()
  {
    if (this.isVisible())
    {
      this.stopAnim();
      this.startAnim();
    }
  }

  /** 
   * Called when the canvas is no longer shown.
   */
  public void hideNotify()
  {
    this.stopAnim();
  }

  public void run()
  {
    try
    {
      int i=0;
      while (!shouldStop)
      {
        this.backgroundImage = (Image)frames.elementAt(i);
        i++;
        if (i >= frames.size())
          i = 0;
        
        Thread.sleep(100);
        this.repaint();
      }
    }
    catch (InterruptedException e)
    {
      e.printStackTrace();
    }
  }
}