package com.synclast.ui.extra;

import java.util.Vector;


import com.synclast.BaseCanvas;
import com.synclast.Graphics;
import com.synclast.Image;
import com.synclast.ui.Color;
import com.synclast.ui.Menu;

public class ImageMenu extends Menu
{
  // Workaround for MIDP 1.0 .class access
  public static Class _class = new ImageMenu().getClass();

  private Vector images = new Vector();
  private int maxVisibleRows = 4;
  private int fixedWidth = 110;
  
  private int currentBorderColor = -2;

  
  protected void init()
  {
    super.init();
    currentBorderColor = properties[UNFOCUSED_BORDER_COLOR];
  }
  
  
  public int getCount()
  {
    return images.size();
  }

  public Image getImage(int index)
  {
    return (Image) images.elementAt(index);
  }

  public void paintClosed(Graphics graphics)
  {
    graphics.setColor(currentBorderColor);
    graphics.setFont(FONT_DEFAULT);
    graphics.drawRect(0, 0, w-1, h-1);
  }
  
  public void paint(Graphics graphics)
  {
    int startingIndex = 0;
    int maxRows = maxVisibleRows;
    
    if (items.size() < maxVisibleRows)
      maxRows = items.size();
      
    if (selected < maxRows)
      startingIndex = 0;
    else if (selected >= items.size()-maxRows)
      startingIndex = items.size()-maxRows;
    else 
      startingIndex = selected;
    
    // the border
    if (currentBorderColor != Color.TRANSPARENT)
    {
      graphics.setColor(currentBorderColor);
      graphics.setFont(FONT_DEFAULT);
      graphics.drawRect(0, 0, w-1, h-1);
    }
    
    // background
    if (properties[BACKGROUND_COLOR] != Color.TRANSPARENT)
    {
      graphics.setColor( properties[BACKGROUND_COLOR] );
      graphics.fillRect(1, 1, w-1, h-1);
    }

    int itemheight = (FONT_DEFAULT.getHeight()+2);
    int item_x_offset = 1;
    int item_y_offset = 1;
    
    for (int i = startingIndex; i < startingIndex+maxRows; i++)
    {
      int fgcolor = (i == selected ? properties[SELECTED_FOREGROUND_COLOR] : properties[FOREGROUND_COLOR]);
      int bgcolor = (i == selected ? properties[SELECTED_BACKGROUND_COLOR] : properties[BACKGROUND_COLOR]);
      
      int hpos = 1;

      if (properties[ITEM_ALIGN] == Graphics.HCENTER)
      {
        hpos = (w - 2 * getTotalInset()) / 2;
      }
      else if (properties[ITEM_ALIGN] == Graphics.RIGHT)
      {
        hpos = w - 2 * getTotalInset();
      }

      // background
      if (bgcolor != Color.TRANSPARENT)
      {
        graphics.setColor( bgcolor );
        graphics.fillRect(hpos, itemheight * (i-startingIndex), w-1, itemheight ); //(itemheight * ((i+1)-startingIndex)));
      }
      
      Image im = getImage(i);
      if (im != null)
      {
        graphics.drawImage(im, hpos+item_x_offset, (itemheight * (i-startingIndex))+item_y_offset, Graphics.TOP | Graphics.LEFT);
        hpos += (im.getWidth() + 2);
      }

      graphics.setFont(i == selected ? FONT_BOLD : FONT_DEFAULT);
      graphics.setColor( fgcolor );

      graphics.drawString((String) items.elementAt(i), hpos+item_x_offset, (itemheight * (i-startingIndex))+item_y_offset, properties[ITEM_ALIGN] | Graphics.TOP);
    }
  }

  public void validate()
  {
    super.validate();
    h = (FONT_DEFAULT.getHeight()+2) * maxVisibleRows;
    if (h == 0)
      h = 5;
    w = fixedWidth;
    invalid = false;
  }
  
  public void add(String item)
  {
    add(null, item, 0);
  }

  public void add(String item, int keyCode)
  {
    add(null, item, keyCode);
  }

  public void add(Image image, String item)
  {
    add(image, item, 0);
  }

  public void add(Image image, String item, int keyCode)
  {
    super.add(item, keyCode);
    images.addElement(image);
    
    if (image != null)
    {
      int iw = image.getWidth();
      
      int cw = FONT_BOLD.charsWidth(item.toCharArray(), 0, item.length()) + 2 * getTotalInset();
      cw += iw;
      if (cw > w) { w = cw; }
      invalidate();
    }
  }

  public void clear()
  {
    images = new Vector();
    items = new Vector();
    keys = new Vector();
    selected = 0;
    invalidate();
  }
  
  public void focus()
  {
    currentBorderColor = properties[FOCUSED_BORDER_COLOR];
    repaint();
  }
  
  public void blur()
  {
    currentBorderColor = properties[UNFOCUSED_BORDER_COLOR];
    repaint();
  }

  public void keyPressed(int keyCode)
  {
    if (maxVisibleRows == 0 &&
        container.getContext().getGameAction(keyCode) == BaseCanvas.FIRE)
    {
      // nothing to do, disable fire events
      return;
    }
      
    super.keyPressed(keyCode);
  }
  
  
  /**
   * @return Returns the fixedWidth.
   */
  public int getFixedWidth()
  {
    return fixedWidth;
  }
  /**
   * @param fixedWidth The fixedWidth to set.
   */
  public void setFixedWidth(int fixedWidth)
  {
    this.fixedWidth = fixedWidth;
  }
  /**
   * @return Returns the maxVisibleRows.
   */
  public int getMaxVisibleRows()
  {
    return maxVisibleRows;
  }
  /**
   * @param maxVisibleRows The maxVisibleRows to set.
   */
  public void setMaxVisibleRows(int maxVisibleRows)
  {
    this.maxVisibleRows = maxVisibleRows;
  }
}