package com.synclast.ui.extra;

import java.util.Vector;

import com.synclast.Font;
import com.synclast.Graphics;
import com.synclast.StyleSheet;
import com.synclast.test.TestRuntimeData;
import com.synclast.test.TestUtils;
import com.synclast.ui.*;

/**
 * The standard Label extended to allow text wrapping
 */
public class MultilineLabel extends ColoredWidget
{
  public static final int FONT = ColoredWidget.LAST_PROPERTY + 1;
  
  protected static final int LAST_PROPERTY = FONT;

  // Workaround for MIDP 1.0 .class access
  public static Class _class = new MultilineLabel("").getClass();

  // Although MIDP has a Font.stringWidth() function, I would
  // tend to assume that the implementation of it still needs
  // to look at the individual characters, so by storing this
  // as a char[] we're possibly getting a slight performance boost.
  private Vector alltext = null;
  protected Font p_font;
  protected String p_text;
  protected boolean p_autoresize = false;
  
  /**
   * Creates a new label widget with the given text. The text will be displayed in the default font.
   * 
   * @exception NullPointerException if text is null.
   */
  public MultilineLabel(String text)
  {
    this(text, Font.getDefaultFont(), false);
  }

  private void mlConfigure(String text, boolean calculateDimensions)
  {
    p_text = text;
    alltext = TestUtils.splitString(p_text, "\n");

    if (calculateDimensions)
    {
      w = 0;
      h = 0;
      for (int i = 0; i < alltext.size(); i++)
      {
        int nw = p_font.stringWidth((String) alltext.elementAt(i));
        if (nw > w) w = nw;
      }
  
      h = p_font.getHeight() * alltext.size();
    }
  }
  
  /**
   * Creates a new label widget with the given text and font style.
   * 
   * @exception NullPointerException if text or font is null.
   */
  public MultilineLabel(String text, Font font, boolean autoresize)
  {
    p_font = font;
    p_autoresize = autoresize;
    mlConfigure(text, true);
  }

  public void paint(Graphics graphics)
  {
    super.paint(graphics);
    graphics.setFont(p_font);
    int ph = p_font.getHeight();
    int total_ph = ph * alltext.size();
    int initialY = h - total_ph;
    for (int i = 0; i < alltext.size(); i++)
    {
      String s = (String) alltext.elementAt(i);
      
      if (s.startsWith("*1*"))
      {
        s = s.substring(3);
        graphics.setColor((TestRuntimeData.getInstance().getVOAdditionalstyle())[2]);
      }
      else if  (s.startsWith("*2*"))
      {
        s = s.substring(3);
        graphics.setColor((TestRuntimeData.getInstance().getVOAdditionalstyle())[3]);
      }
      else if  (s.startsWith("*3*"))
      {
        s = s.substring(3);
        graphics.setColor((TestRuntimeData.getInstance().getVOAdditionalstyle())[4]);
      }
      else if  (s.startsWith("*4*"))
      {
        s = s.substring(3);
        graphics.setColor((TestRuntimeData.getInstance().getVOAdditionalstyle())[5]);
      }
      else
        graphics.setColor(properties[FOREGROUND_COLOR]);

      graphics.drawString(s, 0, initialY, Graphics.TOP | Graphics.LEFT);
      initialY += ph;
    }
  }

  public Widget set(int property, int value)
  {
    if (property == FONT)
    {
      p_font = StyleSheet.getFont(value);
      mlConfigure(p_text, p_autoresize);
    }

    return super.set(property, value);
  }

  public void setText(String text)
  {
    mlConfigure(text, p_autoresize);
  }
}