package com.synclast.ui.extra;

import java.util.Random;

import com.synclast.Graphics;
import com.synclast.SynclastTask;
import com.synclast.ui.Color;
import com.synclast.ui.ColoredWidget;
import com.synclast.ui.containers.Container;

/**
 * A cool animated background widget.  By default, this widget
 * sizes itself to the full canvas size.  Custom width and height
 * may be set after it is added to the canvas.
 */
public class RasterWidget extends ColoredWidget implements Runnable {
    private Random random;
    private SynclastTask task;
    private final static int PERIOD = 200;

    // Set default style properties
    protected void init() {
        super.init();
        set(FOREGROUND_COLOR, Color.WHITE);
    }

    public void paint(Graphics graphics) {
        // This widget always wants its full area
        // to avoid artifacts created by painting
        // only a portion of the screen
        graphics.setClip(graphics.getTranslateX() + x,
                         graphics.getTranslateY() + y,
                         w, h);
        for (int i = 0; i < h; i++) {
            graphics.setColor(random.nextInt() & properties[FOREGROUND_COLOR]);
            graphics.drawRect(0, i, w, i);
        }
    }
    
    public void setContainer(Container container) {
        super.setContainer(container);
        if (container != null) {
            random = new Random();
            task = new SynclastTask(this, 0, PERIOD, true);
        } else {
            task.cancel();
        }
    }

    public void run() {
        if (w == 0 && container.getContext() != null) {
            // First run with a UIContext
            w = container.getContext().getWidth();
            h = container.getContext().getHeight();
            invalidate();
        }
        container.repaint();
    }
}
