/*
    $Id: TwoStateButton.java,v 1.4 2005/11/24 17:32:25 val Exp $

    This file is part of the Synclast UI API.

    The Synclast UI API is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    The Synclast UI API is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with the Synclast UI API; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
package com.synclast.ui.extra;

import com.synclast.BaseCanvas;
import com.synclast.Image;

import com.synclast.ui.*;

/**
 * Encapsulates a selectable widget which may contain either an image
 * or static text.
 */
public class TwoStateButton extends Button implements KeyEventListener {
    // Workaround for MIDP 1.0 .class access
    public static Class _class = new TwoStateButton().getClass();

    private boolean state = true;
    private Image imageTrue = null;
    private Image imageFalse = null;
    
    public TwoStateButton() {
      super("");
    }
    
    protected void init() {
      super.init();
      set(BORDER_COLOR, Color.BLACK);
      set(BORDER_WIDTH, 0);
      set(INSET_WIDTH, 1);
    }
    
    public TwoStateButton(Image imageTrue, Image imageFalse) {
        super("");
        this.imageFalse = imageFalse;
        this.imageTrue = imageTrue;
        w = imageTrue.getWidth();
        h = imageTrue.getHeight();
        setBackgroundImage(imageTrue);
        state = true;
    }

    public void keyPressed(int keyCode)
    {
        switch (container.getContext().getGameAction(keyCode))
        {
          case BaseCanvas.FIRE:
            state = !state;
            if (state)
              setBackgroundImage(imageTrue);
            else
              setBackgroundImage(imageFalse);
            repaint();
            break;
        }

        super.keyPressed(keyCode);
    }

    /**
     * @return Returns the state.
     */
    public boolean getState()
    {
      return state;
    }
    /**
     * @param state The state to set.
     */
    public void setState(boolean state)
    {
      this.state = state;
    }
}
