package val.games.paperotte;

import sdljava.video.SDLColor;
import sdljava.video.SDLSurface;
import val.gp2x.GP2x;


public class ALP_GameCongrats implements GamePhase
{
  private GP2x gp2x;
  private ALP_SharedGameData sharedData;

  private boolean finished = false;
  private int exitCode = GAMEPHASE_ERROR;
  
  
  // ************************ Configuration *************************************
  public int configure(GP2x gp2x, GameData gameData)
  {
    this.gp2x = gp2x;
    this.sharedData = (ALP_SharedGameData)gameData;
    
    finished = false;
    exitCode = GAMEPHASE_ERROR;

    return GAMEPHASE_OK;
  }


  public int prepare_resume()
  {
    return GAMEPHASE_OK;
  }

  
  // ************************ Main Loop *************************************
  public int mainloop()
  {
    try
    {
      while (!finished)
      {
        Thread.sleep(100); // We repaint the screen every 100 milliseconds (about 10 fps)
        events();
        sounds();
        update();
        repaint();
      }
    }
    catch (Exception e)
    {
      e.printStackTrace();
      return GAMEPHASE_ERROR;
    }

    return exitCode;
  }

  
  // ************************ Finalization *************************************
  public int finish()
  {
    return GAMEPHASE_OK;
  }

  
  /**
   * Play any environmental sound
   */
  private void sounds()
  {
    if (finished == true)
    {
      sharedData.squeackSound.playOnce();
    }
  }


  /**
   * Performs actions depending on pressed/clicked buttons
   */
  public void events() throws Exception
  {
    gp2x.getJoyButtonChanges();

    if (gp2x.isButtonPressed(GP2x.VK_UP)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_DOWN)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_LEFT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_RIGHT)) {
    }

    if (gp2x.isButtonPressed(GP2x.VK_UP_LEFT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_UP_RIGHT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_DOWN_LEFT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_DOWN_RIGHT)) {
    }

    if (gp2x.isButtonClicked(GP2x.VK_FY) || gp2x.isButtonClicked(GP2x.VK_FX) ||
        gp2x.isButtonClicked(GP2x.VK_FA) || gp2x.isButtonClicked(GP2x.VK_FB)) {
      exitCode = GAMEPHASE_OK;
      finished = true;
    }
        
  }
  

  /**
   * Redraws completely the screen
   */
  public void repaint()
  {
    SDLColor c = new SDLColor(255,255,255);
    SDLSurface s21 = sharedData.gameFont.writeString("La modalita' Story e' finita, ora", c);
    SDLSurface s22 = sharedData.gameFont.writeString("continuerai ad Infinite Onde !", c);
    SDLSurface s3 = sharedData.gameFont.writeString("Premi A,B,X o Y per continuare...", c);
    
    gp2x.drawImage(sharedData.congrats_background, 0, 0);

    gp2x.drawImage(s21, 20, 120);
    gp2x.drawImage(s22, 20, 140);
    gp2x.drawImage(s3, 20, 170);
    
    gp2x.repaint();

    try {
      s21.freeSurface();
      s22.freeSurface();
      s3.freeSurface();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }

  
  /**
   * Update any animation on the screen
   */
  public void update()
  {
  }
  
}
