package val.games.paperotte;

import sdljava.video.SDLColor;
import sdljava.video.SDLSurface;
import val.gp2x.GP2x;


public class ALP_GameMainMenu implements GamePhase
{
  // additionals
  public static final int GAMEMAINMENU_OPTIONS = 0xD0;
  
  private GP2x gp2x;
  private ALP_SharedGameData sharedData;

  private boolean finished = false;
  private int exitCode = GAMEPHASE_ERROR;
  
  
  // ************************ Configuration *************************************
  public int configure(GP2x gp2x, GameData gameData)
  {
    this.gp2x = gp2x;
    this.sharedData = (ALP_SharedGameData)gameData;
    
    finished = false;
    exitCode = GAMEPHASE_ERROR;

    return GAMEPHASE_OK;
  }


  public int prepare_resume()
  {
    return GAMEPHASE_OK;
  }
  
  
  // ************************ Main Loop *************************************
  public int mainloop()
  {
    try
    {
      while (!finished)
      {
        Thread.sleep(100); // We repaint the screen every 100 milliseconds (about 10 fps)
        events();
        sounds();
        update();
        repaint();
      }
    }
    catch (Exception e)
    {
      e.printStackTrace();
      return GAMEPHASE_ERROR;
    }

    return exitCode;
  }

  
  // ************************ Finalization *************************************
  public int finish()
  {
    return GAMEPHASE_OK;
  }

  
  /**
   * Play any environmental sound
   */
  private void sounds()
  {
    if (finished == true)
    {
      sharedData.squeackSound.playOnce();
    }
  }


  /**
   * Performs actions depending on pressed/clicked buttons
   */
  public void events() throws Exception
  {
    gp2x.getJoyButtonChanges();

    if (gp2x.isButtonPressed(GP2x.VK_UP)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_DOWN)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_LEFT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_RIGHT)) {
    }

    if (gp2x.isButtonPressed(GP2x.VK_UP_LEFT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_UP_RIGHT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_DOWN_LEFT)) {
    }
    if (gp2x.isButtonPressed(GP2x.VK_DOWN_RIGHT)) {
    }

    if (gp2x.isButtonClicked(GP2x.VK_FY)) {
    }
    
    // QUIT
    if (gp2x.isButtonClicked(GP2x.VK_FX)) {
      exitCode = GAMEPHASE_QUIT;
      finished = true;
    }
    // OPTIONS
    if (gp2x.isButtonClicked(GP2x.VK_FA)) {
      exitCode = GAMEMAINMENU_OPTIONS;
      finished = true;
    }
    // OK start game
    if (gp2x.isButtonClicked(GP2x.VK_FB)) {
      exitCode = GAMEPHASE_OK;
      finished = true;
    }
        
  }
  

  /**
   * Redraws completely the screen
   */
  public void repaint()
  {
    SDLColor c = new SDLColor(0, 0, 255);
    SDLColor shade = new SDLColor(255, 255, 255);
    
    SDLSurface s1 = sharedData.gameFontBig.writeStringShaded("Ammazza La Papera", c, shade);
    SDLSurface s2 = sharedData.gameFont.writeStringShaded("B) Inizia !!!", c, shade);
    SDLSurface s3 = sharedData.gameFont.writeStringShaded("A) Opzioni...", c, shade);
    SDLSurface s4 = sharedData.gameFont.writeStringShaded("X) Esci", c, shade);
    
    gp2x.drawImage(sharedData.menu_background, 0, 0);

    gp2x.drawImage(s1, 20, 20);
    gp2x.drawImage(s2, 40, 60);
    gp2x.drawImage(s3, 40, 80);
    gp2x.drawImage(s4, 40, 100);

    gp2x.repaint();

    try {
      s1.freeSurface();
      s2.freeSurface();
      s3.freeSurface();
      s4.freeSurface();
    } catch (Exception e) {
      e.printStackTrace();
    }
  }

  
  /**
   * Update any animation on the screen
   */
  public void update()
  {
  }
  
  
}
