package val.games.paperotte;

import java.io.File;
import java.util.Random;

import com.synclast.Font;

import sdljava.video.SDLSurface;
import sdljava.video.SDLVideo;
import val.gp2x.GP2x;

public class ALP_SharedGameData implements GameData
{
  private final String SOUND_FLAP = "soundfx/flap.wav";
  private final String SOUND_FIRE = "soundfx/44magnum.wav";
  private final String SOUND_SQUEACK = "soundfx/squeak_3.wav";
  private final String SOUND_QUACK = "soundfx/quacks_1.wav";
  
  private final String GAME_BACKGROUND = "gfx/sky.bmp";
  private final String MENU_BACKGROUND = "gfx/menuback.bmp";
  private final String CONGRATS_BACKGROUND = "gfx/congrats.bmp";

  private final String SPRITE_MIRINO = "gfx/mirino.bmp";

  private final String SPRITE_PAPERA_BLU = "gfx/papereblu.bmp";
  private final String SPRITE_PAPERA_ROSSA = "gfx/papererosse.bmp";
  private final String SPRITE_PAPERA_VERDE = "gfx/papereverdi.bmp";

  private final String SPRITE_PAPERA_BLU_MORTA = "gfx/papereblumorte.bmp";
  private final String SPRITE_PAPERA_ROSSA_MORTA = "gfx/papererossemorte.bmp";
  private final String SPRITE_PAPERA_VERDE_MORTA = "gfx/papereverdimorte.bmp";

  public final Random random = new Random(System.currentTimeMillis());

  // Root Path
  public String ApplicationRootPath = null;
  
  // FONT
  public Font gameFont = null;
  public Font gameFontBig = null;
  // Various writings
  // ...
  
  // SOUNDS
  public Sound fireSound = null;
  public Sound flapSound = null;
  public Sound squeackSound = null;
  public Sound quacksSound = null;
  
  // IMAGES / SPRITES
  public SDLSurface game_background = null;
  public SDLSurface menu_background = null;
  public SDLSurface congrats_background = null;
  
  public SDLSurface spriteMirino = null;
  public SDLSurface spritePaperaBlu = null;
  public SDLSurface spritePaperaRossa = null;
  public SDLSurface spritePaperaVerde = null;
  public SDLSurface spritePaperaBluMorta = null;
  public SDLSurface spritePaperaRossaMorta = null;
  public SDLSurface spritePaperaVerdeMorta = null;
  
  // GAME STATE
  public static final int GAME_MODE_STORY = 0x0B;
  public static final int GAME_MODE_INFINITY = 0x0A;
  
  public int gameType = GAME_MODE_STORY;
  public int gameLevel = 1;
  
  public int paperePassate = 0;
  public int papereAmmazzate = 0;
  public int colpiSparati = 0;
 
  
  
  public int initialize(GP2x gp2x)
  {
    try
    {
      // Root Path
      ApplicationRootPath = System.getProperty("application.root.path");
      if (ApplicationRootPath == null)
        ApplicationRootPath = "." + File.separator;
      else
        ApplicationRootPath += File.separator;
          
      // FONT
      gameFont = Font.getFont(Font.FACE_PROPORTIONAL, Font.STYLE_ITALIC, Font.SIZE_MEDIUM);
      gameFontBig = Font.getFont(Font.FACE_PROPORTIONAL, Font.STYLE_BOLD, Font.SIZE_LARGE);
      // Prerender some writings
      // ...
      
      // SOUNDS
      fireSound = this.loadSound(SOUND_FIRE);
      flapSound = this.loadSound(SOUND_FLAP);
      squeackSound = this.loadSound(SOUND_SQUEACK);
      quacksSound = this.loadSound(SOUND_QUACK);
      
      // SPRITES
      game_background = this.loadImage(GAME_BACKGROUND);
      menu_background = this.loadImage(MENU_BACKGROUND);
      congrats_background = this.loadImage(CONGRATS_BACKGROUND);
      
      spriteMirino = this.loadImage(SPRITE_MIRINO);
      spritePaperaBlu = this.loadImage(SPRITE_PAPERA_BLU);
      spritePaperaRossa = this.loadImage(SPRITE_PAPERA_ROSSA);
      spritePaperaVerde = this.loadImage(SPRITE_PAPERA_VERDE);
      spritePaperaBluMorta = this.loadImage(SPRITE_PAPERA_BLU_MORTA);
      spritePaperaRossaMorta = this.loadImage(SPRITE_PAPERA_ROSSA_MORTA);
      spritePaperaVerdeMorta = this.loadImage(SPRITE_PAPERA_VERDE_MORTA);
    }
    catch (Exception e)
    {
      e.printStackTrace();
      return GAMEDATA_KO;
    }
    
    return GAMEDATA_OK;
  }

  public int reset(GP2x gp2x)
  {
    return GAMEDATA_OK;
  }


  private SDLSurface loadImage(String filename) throws Exception
  {
    // Load the sprite image
    SDLSurface sprite = SDLVideo.loadBMP(ApplicationRootPath + filename); // exception thrown if anything bad happends

    // convert to display format
    sprite = sprite.displayFormat(); // original sprite will be cleaned up by gc

    // color-key is near pure yellow
    long colorkey = sprite.mapRGB(0xFF, 0xFD, 2);
    sprite.setColorKey(SDLVideo.SDL_SRCCOLORKEY | SDLVideo.SDL_RLEACCEL, colorkey);
    
    return sprite;
  }
  
  private Sound loadSound(String filename) throws Exception
  {
    return new Sound(ApplicationRootPath + filename);
  }
}
