package val.games.paperotte;

import java.io.File;

import sdljava.video.SDLSurface;
import sdljava.video.SDLVideo;
import val.gp2x.GP2x;


public class AmmazzaLaPapera
{
  private GP2x gp2x = null;
  private ALP_SharedGameData shared = null;
  
  private boolean finished = false;

  // ************************ Start *************************************
  public AmmazzaLaPapera(GP2x gp2x) throws Exception
  {
    // initialize the screen/joystick hardware devices
    this.gp2x = gp2x;

    // Root Path
    String ApplicationRootPath = System.getProperty("application.root.path");
    if (ApplicationRootPath == null)
      ApplicationRootPath = "." + File.separator;
    else
      ApplicationRootPath += File.separator;

    SDLSurface loading = SDLVideo.loadBMP(ApplicationRootPath + "gfx/loading.bmp").displayFormat();
    gp2x.drawImage(loading, 0, 0);
    gp2x.repaint();
    
    shared = new ALP_SharedGameData();
    if (shared.initialize(gp2x) != GameData.GAMEDATA_OK)
    {
      finished = true;
    }
    
    loading = null;
  }


  /*
   * Game mechanics:
   * - main menu (play, options, quit)
   *  - play: reset shared, start level 1
   *   - pause screen
   *    - resume
   *    - quit to menu
   *    - quit game
   *  - options (...)
   *   - quit to menu
   *  - quit
   */
  public void mainGameLoop()
  {
    try
    {
      while (!finished)
      {
        GamePhase gameMainMenu = new ALP_GameMainMenu();
        
        if (gameMainMenu.configure(gp2x, shared) != GamePhase.GAMEPHASE_ERROR)
        {
          int c1 = gameMainMenu.mainloop();
          gameMainMenu.finish();
          switch (c1)
          {
            case GamePhase.GAMEPHASE_OK: // success, start game
            {
              GamePhase gameLevel = new ALP_GameLevel();
              if (gameLevel.configure(gp2x, shared) != GamePhase.GAMEPHASE_ERROR)
              {
                boolean playing = true;
                while (playing)
                {
                  int c2 = gameLevel.mainloop();
  
                  switch (c2)
                  {
                    case GamePhase.GAMEPHASE_OK: // success, next level
                    {
                      gameLevel = new ALP_GameLevel();
                      if (gameLevel.configure(gp2x, shared) == GamePhase.GAMEPHASE_ERROR)
                        playing = false;
                    }
                    break;
                    case GamePhase.GAMEPHASE_KO: // unsuccess, game over, return to menu
                    {
                      playing = false;
                    }
                    break;
                    case GamePhase.GAMEPHASE_QUIT: // quit the game
                    {
                      playing = false;
                      finished = true;
                    }
                    break;
                    case GamePhase.GAMEPHASE_PAUSE: // pause, go to pause screen
                    {
                      // go to pause screen
                      GamePhase gamePause = new ALP_GamePause();
                      if (gamePause.configure(gp2x, shared) != GamePhase.GAMEPHASE_ERROR)
                      {
                        int c3 = gamePause.mainloop();
                        gamePause.finish();
                        
                        switch (c3)
                        {
                          case GamePhase.GAMEPHASE_OK: // resume game
                          {
                            // prepare the game level mainloop to be resumed
                            gameLevel.prepare_resume();
                          }
                          break;
                          case GamePhase.GAMEPHASE_KO: // game over, return to menu
                          {
                            playing = false;
                          }
                          break;
                          case GamePhase.GAMEPHASE_QUIT: // quit the game
                          {
                            playing = false;
                            finished = true;
                          }
                          break;
                        }
                      }
                    }
                    break;
                  }
                }
                gameLevel.finish();
              }
            }
            break;

            case ALP_GameMainMenu.GAMEMAINMENU_OPTIONS: // options screen
            {
              GamePhase gameMenuOptions = new ALP_GameMenuOptions();
              if (gameMenuOptions.configure(gp2x, shared) != GamePhase.GAMEPHASE_ERROR)
              {
                gameMenuOptions.mainloop();
                gameMenuOptions.finish();
                // menu options can only return ok
              }
            }
            break;

            case GamePhase.GAMEPHASE_QUIT: // quit the game
            finished = true;
            break;
          }
        }
        
        gameMainMenu.finish();
      }
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
    
  }

}
