package val.games.paperotte;

import val.gp2x.GP2x;

public interface GamePhase
{
  /**
   * configuration went wrong
   */
  public static final int GAMEPHASE_ERROR = 0xF2;
  
  /**
   * user finished this phase successfully
   */
  public static final int GAMEPHASE_OK = 0xF0;
  /**
   * user finished this phase unsuccessfully
   */
  public static final int GAMEPHASE_KO = 0xF1;

  /**
   * user requested to quit the game, the game loop can be resumed
   */
  public static final int GAMEPHASE_QUIT = 0xF5;
  /**
   * user requested to pause the game, the game loop can be resumed
   */
  public static final int GAMEPHASE_PAUSE = 0xF6;

  /**
   * Configure the game phase to be displayed
   * @param gp2x the hardware interface
   * @param gameData a shared instance of game data
   * @return an exit code
   */
  public int configure(GP2x gp2x, GameData gameData);
  
  /**
   * Prepare the mainloop to be resumed
   * @return an exit code
   */
  public int prepare_resume();
  
  /**
   * Entire main loop, manages the life of this phase
   * @return an exit code
   */
  public int mainloop();
  
  /**
   * deinit the phase, ready to be destroyed
   * @return an exit code
   */
  public int finish();
}
