package val.games.paperotte;

import sdljava.video.SDLSurface;
import val.games.paperotte.functions.Function;
import val.gp2x.GP2x;


class SerieOfPaperotte
{
  private Paperotta allPaperotte[];
  private int hSpeed;
  private SDLSurface spriteSurface;

  /**
   * Create a serie of Paperotte
   * 
   * @param number of paperotte in the serie
   * @param offset distance between two paperotte
   * @param speed horizontal speed of paperotte
   * @param spriteFile name of the sprite bitmap
   * @param function wave function
   * @param sprite image sprite name
   */
  public SerieOfPaperotte(GP2x gp2x, int number, int offset, int speed, SDLSurface spriteSurface, Function function)
  {
    this.allPaperotte = new Paperotta[number];
    this.hSpeed = speed;
    this.spriteSurface = spriteSurface;
    
    for (int i=0; i<number; i++)
    {
      Sprite s = new Sprite(gp2x.getFramebuffer(), 3, spriteSurface);
      Paperotta p = new Paperotta(function, s);
      
      p.setInitialPosition(-(i*offset), 100);
      
      allPaperotte[i] = p;
    }
  }

  public boolean move()
  {
    boolean wasReduced = false;
    
    for (int i=0; i<allPaperotte.length; i++)
    {
      if (allPaperotte[i] == null)
        continue;
      
      allPaperotte[i].move(hSpeed);
      
      if (allPaperotte[i].isOutOfGame())
      {
        allPaperotte[i] = null;
        wasReduced = true;
      }
    }
    
    return wasReduced;
  }

  public Paperotta isHit(int x, int y)
  {
    for (int i=0; i<allPaperotte.length; i++)
      if (allPaperotte[i] != null && allPaperotte[i].isHit(x, y))
          return allPaperotte[i];
    
    return null;
  }

  public void redraw()
  {
    for (int i=0; i<allPaperotte.length; i++)
      if (allPaperotte[i] != null)
        allPaperotte[i].redraw();
  }

  public boolean hasElementsInGame()
  {
    for (int i=0; i<allPaperotte.length; i++)
      if (allPaperotte[i] != null)
        return true;
    
    return false;
  }

  public SDLSurface getSpriteSurface()
  {
    return spriteSurface;
  }

}
