package val.games.paperotte;

import java.util.Random;

import sdljava.SDLException;
import sdljava.video.SDLRect;
import sdljava.video.SDLSurface;

public class Sprite
{
  static Random random = new Random(System.currentTimeMillis());
  
  private SDLSurface screen;

  public SDLSurface spriteSurface;
  public SDLRect position;
  public int frameWidth, frameHeight;
  public int halfFrameWidth, halfFrameHeight;
  
  private SDLRect frameRects[];
  private int frameSeries[];
  private int currentFrame;
  
  public Sprite(SDLSurface screen, int numFrames, SDLSurface spriteSurface)
  {
    try
    {
      // Load the sprite image
      this.spriteSurface = spriteSurface;
  
      frameWidth = spriteSurface.getWidth();
      frameHeight = spriteSurface.getHeight();
      halfFrameWidth = frameWidth / 2;
      halfFrameHeight = frameHeight / 2;

      frameWidth = frameWidth / numFrames;

      frameRects = new SDLRect[numFrames];
      frameSeries = new int[numFrames+1];

      for (int x=0; x<numFrames; x++)
        frameSeries[x] = x;
                    
      for (int x=0; x<numFrames; x++)
        frameRects[x] = new SDLRect(x*frameWidth, 0, frameWidth, frameHeight);
        
      position = new SDLRect(0, 0, frameWidth, frameHeight);
      currentFrame = random.nextInt(frameSeries.length);
      
      this.screen = screen;
    }
    catch (Exception e)
    {
      e.printStackTrace();
    }
  }

  public void keepInsideScreen()
  {
    if (position.x < 0) position.x = 0;
    if (position.y < 0) position.y = 0;
    if (position.x > screen.getWidth()-frameWidth) position.x = screen.getWidth()-frameWidth;
    if (position.y > screen.getHeight()-frameHeight) position.y = screen.getHeight()-frameHeight;
  }
  
  public void redraw() throws SDLException
  {
    // blit to screen surface
    spriteSurface.blitSurface(frameRects[frameSeries[currentFrame]], screen, position);
    currentFrame++;
    if (currentFrame >= frameSeries.length)
      currentFrame = 0;
  }
}
