package sdljava;

import java.io.File;

import sdljava.SDLMain;
import sdljava.SDLException;
import sdljava.SDLTest;
import sdljava.event.SDLEvent;
import sdljava.event.SDLEventState;
import sdljava.event.SDLJoyButtonEvent;
import sdljava.event.SDLKeyboardEvent;
import sdljava.joystick.SDLJoystick;
import sdljava.ttf.SDLTTF;
import sdljava.ttf.SDLTrueTypeFont;
import sdljava.video.GammaTable;
import sdljava.video.SDLColor;
import sdljava.video.SDLRect;
import sdljava.video.SDLSurface;
import sdljava.video.SDLVideo;
import sdljava.video.SDLVideoInfo;
import sdljava.x.swig.SWIG_SDLEvent;

public class HelloWorld extends SDLTest
{
  SDLSurface framebuffer = null;
  SDLJoystick joystick = null;

  public void init() throws SDLException
  {
    SDLMain.init(SDLMain.SDL_INIT_VIDEO | SDLMain.SDL_INIT_JOYSTICK);
    SDLTTF.init();
    System.out.println("Video subsystem initialized");

    SDLEvent.joystickEventState(SDLEventState.ENABLE);
    
    int count = SDLJoystick.numJoysticks();
    System.out.println("numJoysticks=" + count);
    if (count < 1)
    {
      System.out.println("No joystick devices available");
    }
    else
    {
      System.out.println("opening first joystick device");
      joystick = SDLJoystick.joystickOpen(0);
      System.out.println("joystick opened");
    }
    
    // framebuffer = SDLVideo.setVideoMode(800, 600, 32, (long) SDLVideo.SDL_HWSURFACE | SDLVideo.SDL_DOUBLEBUF | SDLVideo.SDL_RESIZABLE);
    framebuffer = SDLVideo.setVideoMode(640, 480, 32, (long) SDLVideo.SDL_SWSURFACE );
    SWIG_SDLEvent.SDL_ShowCursor(0);

    // videoDriverName causes crash right now...not sure why
    // System.out.println("Video Driver=" + SDLVideo.videoDriverName());
    System.out.println("framebuffer=" + framebuffer);
  }


  public void testLoadBMP() throws SDLException
  {
    SDLSurface bmp = SDLVideo.loadBMP("testdata" + File.separator + "test_bmp.bmp");
    SDLRect src = new SDLRect(0, 0, bmp.getWidth(), bmp.getHeight());

    long start = System.currentTimeMillis();
    bmp.blitSurface(src, framebuffer, src);
    long end = System.currentTimeMillis();
    framebuffer.flip();
  }

  public void destroy() throws SDLException
  {
    SDLTTF.quit();
    SDLMain.quit();
  }

  public HelloWorld()
  {
  }

  public static void main(String[] args)
  {
    HelloWorld t = null;
    try
    {
      t = new HelloWorld();
      t.init();
      
      SDLSurface bmp = SDLVideo.loadBMP("testdata" + File.separator + "test_bmp.bmp");
      SDLRect src = new SDLRect(0, 0, bmp.getWidth(), bmp.getHeight());
      SDLRect dst = new SDLRect(0, 0);
      
      SDLTrueTypeFont    font = SDLTTF.openFont("testdata" + File.separator + "arial.ttf", 24);
      SDLSurface solid = font.renderTextSolid("This is Solid text", new SDLColor(255, 255,255,255));
      SDLSurface blended = font.renderTextBlended("This is Blended text", new SDLColor(255, 255,255,255));
      SDLSurface shaded = font.renderTextShaded("This is Shaded text", new SDLColor(255, 255,255,255), new SDLColor(255, 0,0,0) );

      int x = 0;
      while (true)
      {
        SDLEvent e = SDLEvent.pollEvent();
        if (e != null && e instanceof SDLKeyboardEvent) // && e instanceof SDLJoyButtonEvent)
        {
          System.out.println("Evento: "+e);
          break;
        }

        t.framebuffer.fillRect(new SDLRect(0, 0, t.framebuffer.getWidth(), t.framebuffer.getHeight()), 0x00000000);

        dst.setX(x);

        dst.setY(0);
        bmp.blitSurface(src, t.framebuffer, dst);
        
        dst.setY(200);
        solid.blitSurface(null, t.framebuffer, dst);
        
        dst.setY(300);
        blended.blitSurface(null, t.framebuffer, dst);
        
        dst.setY(400);
        shaded.blitSurface(null, t.framebuffer, dst);
        
        t.framebuffer.flip();

        x+=1;
        if (x > t.framebuffer.getWidth())
          x = -200;
      }
      t.testLoadBMP();

      t.destroy();
    }
    catch (Exception ee)
    {
      ee.printStackTrace();
    } // catch
  }
}